@@ -78,8 +78,8 @@ typedef unsigned int gsize;
 #define g_memmove(d,s,n) G_STMT_START { memmove ((d), (s), (n)); } G_STMT_END
 
 #define GLIB_MAJOR_VERSION 2
-#define GLIB_MINOR_VERSION 4
-#define GLIB_MICRO_VERSION 4
+#define GLIB_MINOR_VERSION 6
+#define GLIB_MICRO_VERSION 1
 
 #define G_OS_UNIX
 
@@ -93,6 +93,12 @@ typedef unsigned int gsize;
 #define G_HAVE___INLINE__ 1
 #endif	/* !__cplusplus */
 
+#ifdef	__cplusplus
+#define G_CAN_INLINE	1
+#else	/* !__cplusplus */
+#define G_CAN_INLINE	1
+#endif
+
 #ifndef __cplusplus
 # define G_HAVE_ISO_VARARGS 1
 #endif
@@ -111,6 +117,8 @@ typedef unsigned int gsize;
 #define G_HAVE_GNUC_VARARGS 1
 #define G_HAVE_GROWING_STACK 0
 
+#define G_HAVE_GNUC_VISIBILITY 1
+#define G_GNUC_INTERNAL __attribute__((visibility("hidden")))
 
 #define G_THREADS_ENABLED
 #define G_THREADS_IMPL_POSIX
